Notifier class mixin

Implemented types
Implementers

Constructors

Notifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
override
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() → void
removeListener(VoidCallback listener) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

debugAssertNotDisposed(Notifier notifier) bool
maybeDispatchObjectCreation(Notifier object) → void